>From 421bd1080a9ad5aa05e26f3c2cc32c5e4a163f1b Mon Sep 17 00:00:00 2001
From: Alvaro Herrera <alvherre@alvh.no-ip.org>
Date: Tue, 29 Apr 2014 15:51:19 -0400
Subject: [PATCH 09/36] core: support ALTER TABLESPACE MOVE in event trigs

This operation actually affects tables, not tablespaces, so it doesn't
make sense to avoid support for it.
---
 src/backend/commands/event_trigger.c |  1 +
 src/backend/tcop/utility.c           | 11 +++++------
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/src/backend/commands/event_trigger.c b/src/backend/commands/event_trigger.c
index 1285fd0..bfab1d7 100644
--- a/src/backend/commands/event_trigger.c
+++ b/src/backend/commands/event_trigger.c
@@ -250,6 +250,7 @@ check_ddl_tag(const char *tag)
 		pg_strcasecmp(tag, "REFRESH MATERIALIZED VIEW") == 0 ||
 		pg_strcasecmp(tag, "ALTER DEFAULT PRIVILEGES") == 0 ||
 		pg_strcasecmp(tag, "ALTER LARGE OBJECT") == 0 ||
+		pg_strcasecmp(tag, "ALTER TABLESPACE MOVE") == 0 ||
 		pg_strcasecmp(tag, "DROP OWNED") == 0)
 		return EVENT_TRIGGER_COMMAND_TAG_OK;
 
diff --git a/src/backend/tcop/utility.c b/src/backend/tcop/utility.c
index 3423898..5553221 100644
--- a/src/backend/tcop/utility.c
+++ b/src/backend/tcop/utility.c
@@ -506,11 +506,6 @@ standard_ProcessUtility(Node *parsetree,
 			AlterTableSpaceOptions((AlterTableSpaceOptionsStmt *) parsetree);
 			break;
 
-		case T_AlterTableSpaceMoveStmt:
-			/* no event triggers for global objects */
-			AlterTableSpaceMove((AlterTableSpaceMoveStmt *) parsetree);
-			break;
-
 		case T_TruncateStmt:
 			ExecuteTruncate((TruncateStmt *) parsetree);
 			break;
@@ -1304,6 +1299,10 @@ ProcessUtilitySlow(Node *parsetree,
 				ExecAlterObjectSchemaStmt((AlterObjectSchemaStmt *) parsetree);
 				break;
 
+			case T_AlterTableSpaceMoveStmt:
+				AlterTableSpaceMove((AlterTableSpaceMoveStmt *) parsetree);
+				break;
+
 			case T_AlterOwnerStmt:
 				ExecAlterOwnerStmt((AlterOwnerStmt *) parsetree);
 				break;
@@ -1806,7 +1805,7 @@ CreateCommandTag(Node *parsetree)
 			break;
 
 		case T_AlterTableSpaceMoveStmt:
-			tag = "ALTER TABLESPACE";
+			tag = "ALTER TABLESPACE MOVE";
 			break;
 
 		case T_CreateExtensionStmt:
-- 
1.9.1

